{ config, pkgs, ... }:
let
  secrets = import ./secrets.nix;
  hostname = "code.dumpstack.io";
in {
  imports = [ ./hardware-configuration.nix ];

  boot.loader.grub.enable = true;
  boot.loader.grub.version = 2;
  boot.loader.grub.device = "/dev/vda";

  networking.hostName = "${hostname}";

  networking.firewall =  {
    enable = true;
    allowedTCPPorts = [ 80 443 ];
  };

  users.extraUsers.root = {
    openssh.authorizedKeys.keys = [ secrets.pubkey ];
  };

  services.openssh.enable = true;

  environment.systemPackages = with pkgs; [
    vim
  ];

  services.gitea = {
    enable = true;
    appName = "${hostname}";
    domain = "${hostname}";
    rootUrl = "https://${hostname}";
    extraConfig = ''
      [service]
      DISABLE_REGISTRATION = true

      [ui]
      DEFAULT_THEME = arc-green
    '';
  };

  services.nginx = {
    enable = true;
    virtualHosts."${hostname}" = {
      enableACME = true;
      forceSSL = true;

      locations."/".proxyPass = "http://127.0.0.1:3000";
    };
  };

  system.stateVersion = "18.09";
  system.autoUpgrade.enable = true;
}
